==> xsns_1.0.0.zip: xsns_1.0.0/xoops_trust_path/modules/xsns/act/admin/defaultAction.php <==
<?php
class defaultAction extends adminAction
{
function dispatch(&$context)
{
	$this->replaceMypage();
	
	header('Location: index.php?'.APP_ACTION_ARG.'=category');
	exit;
}

// ޥڡ  ȾڡΥե֤
function replaceMypage()
{
	if(defined('XOOPS_CUBE_LEGACY')){
		return true;
	}
	
	global $xoopsModuleConfig, $mydirname;
	
	$userinfo_file = XOOPS_ROOT_PATH.'/userinfo.php';
	$edituser_file = XOOPS_ROOT_PATH.'/edituser.php';
	$userinfo_file_r = APP_TRUST_PATH.'/x20/userinfo.php';
	$edituser_file_r = APP_TRUST_PATH.'/x20/edituser.php';
	$userinfo_file_b = APP_TRUST_PATH.'/x20/bak_userinfo.php';
	$edituser_file_b = APP_TRUST_PATH.'/x20/bak_edituser.php';
	
	if(file_exists($userinfo_file) && file_exists($edituser_file)){
		if($xoopsModuleConfig['mypage_use']
		   && file_exists($userinfo_file_r)
		   && file_exists($edituser_file_r)
		   && md5_file($userinfo_file) != md5_file($userinfo_file_r)
		   && md5_file($edituser_file) != md5_file($edituser_file_r)){
			
			// ȾڡХåå  ޥڡ֤
			@copy($userinfo_file, $userinfo_file_b);
			@copy($edituser_file, $edituser_file_b);
			@copy($userinfo_file_r, $userinfo_file);
			@copy($edituser_file_r, $edituser_file);
			
			if($handle = fopen(APP_TRUST_PATH.'/x20/dirname.dat', 'w')){
				fwrite($handle, $mydirname);
				fclose($handle);
			}
			else{
				return false;
			}
		}
		elseif(!$xoopsModuleConfig['mypage_use']
			   && file_exists($userinfo_file_b)
			   && file_exists($edituser_file_b)
			   && md5_file($userinfo_file) == md5_file($userinfo_file_r)
			   && md5_file($edituser_file) == md5_file($edituser_file_r)){
			
			// ξ֡ʥȾڡˤ᤹
			@copy($userinfo_file_b, $userinfo_file);
			@copy($edituser_file_b, $edituser_file);
		}
	}
	return true;
}

}

?>

==> xsns_1.0.1.zip: xsns_1.0.1/xoops_trust_path/modules/xsns/act/admin/defaultAction.php <==
<?php
class defaultAction extends adminAction
{

function dispatch(&$context)
{
	$err = $this->checkPermission();
	if(!is_array($err) || count($err) > 0){
		$context->setAttributes('perm_error', $err);
	}
	
	if(!$this->replaceMypage()){
		$context->setAttributes('mypage_error', 1);
	}
}

// ޥڡ  ȾڡΥե֤
function replaceMypage()
{
	if(defined('XOOPS_CUBE_LEGACY')){
		return true;
	}
	
	global $xoopsModuleConfig, $mydirname;
	
	$userinfo_file = XOOPS_ROOT_PATH.'/userinfo.php';
	$edituser_file = XOOPS_ROOT_PATH.'/edituser.php';
	$userinfo_file_r = APP_TRUST_PATH.'/x20/userinfo.php';
	$edituser_file_r = APP_TRUST_PATH.'/x20/edituser.php';
	$userinfo_file_b = APP_TRUST_PATH.'/x20/bak_userinfo.php';
	$edituser_file_b = APP_TRUST_PATH.'/x20/bak_edituser.php';
	
	if(file_exists($userinfo_file) && file_exists($edituser_file)){
		if($xoopsModuleConfig['mypage_use']
		   && file_exists($userinfo_file_r)
		   && file_exists($edituser_file_r)
		   && md5_file($userinfo_file) != md5_file($userinfo_file_r)
		   && md5_file($edituser_file) != md5_file($edituser_file_r)){
			
			// ȾڡХåå  ޥڡ֤
			@copy($userinfo_file, $userinfo_file_b);
			@copy($edituser_file, $edituser_file_b);
			@copy($userinfo_file_r, $userinfo_file);
			@copy($edituser_file_r, $edituser_file);
			
			if($handle = @fopen(APP_TRUST_PATH.'/x20/dirname.dat', 'w')){
				fwrite($handle, $mydirname);
				fclose($handle);
			}
			else{
				return false;
			}
		}
		elseif(!$xoopsModuleConfig['mypage_use']
			   && file_exists($userinfo_file_b)
			   && file_exists($edituser_file_b)
			   && md5_file($userinfo_file) == md5_file($userinfo_file_r)
			   && md5_file($edituser_file) == md5_file($edituser_file_r)){
			
			// ξ֡ʥȾڡˤ᤹
			@copy($userinfo_file_b, $userinfo_file);
			@copy($edituser_file_b, $edituser_file);
		}
		return true;
	}
	return false;
}

}

?>
